.\" -*- nroff -*- generated from .Rd format
.de PF
,br
.ne 2
.ft 3
.nf
..
.de FP
.br
.ne 2
.ft 1
.fi
..
.BG
.FN fdr
.TL
False Discovery Rate multiple testing
.DN
This is the main user function designed for general usage for determining significance based on the FDR approach.
.CS

fdr(pvals,qlevel=0.05,method="original",adjustment.method=NULL,adjustment.args=NULL)
.RA
.AG pvals
a vector of pvals on which to conduct the multiple
testing.
.AG qlevel
the proportion of false positives desired.
.AG method
an optional character string indicating the method for performing the testing.  'original' follows Benjamini & Hochberg (1995); 'general' is much more conservative, requiring no assumptions on the p-values (see Benjamini & Yekutieli (2001)).  We recommend using 'original', and if desired, using 'adjustment.method="mean" ' to increase power.
.AG adjustment.method
an optional character string indicating the
method for increasing the power of the procedure by estimating the
proportion of alternative p-values, one of "mean", the modified
Storey estimator that we suggest in Ventura et al. (2004), "storey",
the method of Storey (2002), or "two-stage", the iterative approach
of Benjamini et al. (2001)
.AG adjustment.args
an optional list giving the arguments to
adjustment.method; see 'prop.alt' for description, but
note that for "two-stage", the values of qlevel and fdr.method are taken from the qlevel and method arguments to 'fdr'.
.RT
NULL if no significant tests, or a vector of the indices of the significant tests
.SH REFERENCES
Ventura, V., C.J. Paciorek, and J.S. Risbey (2004)
Controlling the proportion of falsely-rejected hypotheses when
conducting multiple tests with climatological data.
Journal of Climate, in press.  Also Carnegie Mellon University, Department of
Statistics technical report 775
<URL: www.stat.cmu.edu/tr/tr775/tr775.html>
.IP "" 
Benjamini, Y, and Y. Hochberg (1995) Controlling the false discovery rate: a practical and powerful approach to multiple testing.  JRSSB 57:289-300.
.IP "" 
Benjamini, Y. and D. Yekutieli (2001)  The control of the false
discovery rate in multiple testing under dependency. Annals of
Statistics 29:1165-1188.
.IP "" 
Benjamini, Y., A. Krieger, and D. Yekutieli (2001)  Two staged linear
step up FDR controlling procedure.  Technical Report, Department of
Statistics and Operations Research, Tel Aviv University.  <URL: http://www.math.tau.ac.il/~ybenja/Papers.html>
.IP "" 
Storey, J. {2002}  A direct approach to false discovery rates.  JRSSB 64: 479-498.

.EX
signif <- fdr(pvals,method="original",adjustment.method="mean")
.KW false discovery rate
.KW multiple testing
.WR
