\name{prop.alt}
\title{Internal function for FDR multiple testing}
\description{This is an internal function that calculates an estimate of
  a, the proportion of alternative hypotheses, using one of several
  methods.
}
\usage{prop.alt(pvals,adjustment.method="mean",adjustment.args=list(edf.lower=0.8,num.steps=20))}
\arguments{
  \item{pvals}{a vector of pvals on which to conduct the multiple
    testing.}
  \item{adjustment.method}{an optional character string indicating the
    method for increasing the power of the procedure by estimating the
    proportion of alternative p-values, one of "mean", the modified
    Storey estimator that we suggest in Ventura et al. (2004), "storey",
    the method of Storey (2002), or "two-stage", the iterative approach
    of Benjamini et al. (2001)}
  \item{adjustment.args}{a list giving the arguments to
    \code{adjustment.method}:
    
    for \code{adjustment.method="mean"}, specify edf.lower, the smallest
    quantile at which to estimate a, and num.steps, the number of quantiles to
    use - the approach uses the average of the Storey (2002) estimator
    for the num.steps quantiles starting at edf.lower and finishing just
    less than 1

    for \code{adjustment.method="storey"}, specify edf.quantile, the quantile
    at which to calculate the estimator
    
    for \code{adjustment.method="two-stage"}, the method uses a standard FDR
    approach to estimate which p-values are significant; this number is
    the estimate of a; therefore the method requires specification of
    qlevel, the proportion of false positives and fdr.method ('original'
    or 'general'), the FDR method to be used.  We do not recommend
    'general' as this is very conservative and will underestimate a.
  }
}
\value{
  estimate of a, the number of alternative hypotheses
}
\references{see \code{fdr}.}
\author{ Chris Paciorek \email{paciorek AT alumni.cmu.edu}}
\examples{
a <- prop.alt(pvals,adjustment.method="mean",adjustment.args=list(edf.lower=0.8,num.steps=20))

a <- prop.alt(pvals,adjustment.method="storey",adjustment.args=list(edf.quantile=0.8))

a <- prop.alt(pvals,adjustment.method="two-stage",adjustment.args=list(qlevel=0.05,fdr.method='original'))
}
\keyword{false discovery rate}\keyword{multiple testing}
