.\" -*- nroff -*- generated from .Rd format
.de PF
,br
.ne 2
.ft 3
.nf
..
.de FP
.br
.ne 2
.ft 1
.fi
..
.BG
.FN prop.alt
.TL
Internal function for FDR multiple testing
.DN
This is an internal function that calculates an estimate of
a, the proportion of alternative hypotheses, using one of several
methods.
.CS
prop.alt(pvals,adjustment.method="mean",adjustment.args=list(edf.lower=0.8,num.steps=20))
.RA
.AG pvals
a vector of pvals on which to conduct the multiple
testing.
.AG adjustment.method
an optional character string indicating the
method for increasing the power of the procedure by estimating the
proportion of alternative p-values, one of "mean", the modified
Storey estimator that we suggest in Ventura et al. (2004), "storey",
the method of Storey (2002), or "two-stage", the iterative approach
of Benjamini et al. (2001)
.AG adjustment.args
a list giving the arguments to
'adjustment.method':
.IP "" 
for 'adjustment.method="mean"', specify edf.lower, the smallest
quantile at which to estimate a, and num.steps, the number of quantiles to
use - the approach uses the average of the Storey (2002) estimator
for the num.steps quantiles starting at edf.lower and finishing just
less than 1
.IP "" 
for 'adjustment.method="storey"', specify edf.quantile, the quantile
at which to calculate the estimator
.IP "" 
for 'adjustment.method="two-stage"', the method uses a standard FDR
approach to estimate which p-values are significant; this number is
the estimate of a; therefore the method requires specification of
qlevel, the proportion of false positives and fdr.method ('original'
or 'general'), the FDR method to be used.  We do not recommend
'general' as this is very conservative and will underestimate a.

.RT
estimate of a, the number of alternative hypotheses
.SH REFERENCES
see 'fdr'.

.EX
a <- prop.alt(pvals,adjustment.method="mean",adjustment.args=list(edf.lower=0.8,num.steps=20))

a <- prop.alt(pvals,adjustment.method="storey",adjustment.args=list(edf.quantile=0.8))

a <- prop.alt(pvals,adjustment.method="two-stage",adjustment.args=list(qlevel=0.05,fdr.method='original'))
.KW false discovery rate
.KW multiple testing
.WR
